==> jc-1.4.0.tar.gz: javax/print/attribute/standard/JobImpressionsSupported.h <==
// public final class javax.print.attribute.standard.JobImpressionsSupported

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 918eb93a2f6dd324 javax_print_attribute_SetOfIntegerSyntax
// @dep_class eb46a4ecfecc3d56 javax_print_attribute_standard_JobImpressionsSupported

// header file dependencies
// @dep_header javax_print_attribute_SetOfIntegerSyntax

#include "javax/print/attribute/SetOfIntegerSyntax.h"

#ifndef _JC_javax_print_attribute_standard_JobImpressionsSupported_H_
#define _JC_javax_print_attribute_standard_JobImpressionsSupported_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_JobImpressionsSupported$sub_refs	_jc_javax_print_attribute_standard_JobImpressionsSupported$sub_refs;
typedef struct _jc_javax_print_attribute_standard_JobImpressionsSupported$sub_nonrefs	_jc_javax_print_attribute_standard_JobImpressionsSupported$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobImpressionsSupported$refs	_jc_javax_print_attribute_standard_JobImpressionsSupported$refs;
typedef struct _jc_javax_print_attribute_standard_JobImpressionsSupported$nonrefs	_jc_javax_print_attribute_standard_JobImpressionsSupported$nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobImpressionsSupported$object	_jc_javax_print_attribute_standard_JobImpressionsSupported$object;

typedef struct _jc_javax_print_attribute_standard_JobImpressionsSupported$fields_struct	_jc_javax_print_attribute_standard_JobImpressionsSupported$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_JobImpressionsSupported$vmethods	_jc_javax_print_attribute_standard_JobImpressionsSupported$vmethods;
typedef const struct _jc_javax_print_attribute_standard_JobImpressionsSupported$vtable	_jc_javax_print_attribute_standard_JobImpressionsSupported$vtable;
typedef const struct _jc_javax_print_attribute_standard_JobImpressionsSupported$vtype	_jc_javax_print_attribute_standard_JobImpressionsSupported$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24JobImpressionsSupported;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_JobImpressionsSupported$fields_struct _jc_javax_print_attribute_standard_JobImpressionsSupported$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_JobImpressionsSupported$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_javax_print_attribute_standard_JobImpressionsSupported$object *, jint, jint);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobImpressionsSupported$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_JobImpressionsSupported$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_JobImpressionsSupported$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_JobImpressionsSupported$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_JobImpressionsSupported$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_JobImpressionsSupported$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobImpressionsSupported$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_JobImpressionsSupported$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_JobImpressionsSupported$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_SetOfIntegerSyntax$vmethods	javax_print_attribute_SetOfIntegerSyntax;
	_jc_javax_print_attribute_standard_JobImpressionsSupported$vmethods	javax_print_attribute_standard_JobImpressionsSupported;
};

// Vtype
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_JobImpressionsSupported$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$refs {
    _jc_javax_print_attribute_standard_JobImpressionsSupported$sub_refs	javax_print_attribute_standard_JobImpressionsSupported;
    _jc_javax_print_attribute_SetOfIntegerSyntax$sub_refs	javax_print_attribute_SetOfIntegerSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_SetOfIntegerSyntax$sub_nonrefs	javax_print_attribute_SetOfIntegerSyntax;
    _jc_javax_print_attribute_standard_JobImpressionsSupported$sub_nonrefs	javax_print_attribute_standard_JobImpressionsSupported;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$object {
	_jc_javax_print_attribute_standard_JobImpressionsSupported$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_JobImpressionsSupported$vtype	*vtype;
	_jc_javax_print_attribute_standard_JobImpressionsSupported$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_JobImpressionsSupported$vtype _jc_javax_print_attribute_standard_JobImpressionsSupported$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_JobImpressionsSupported, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_JobImpressionsSupported$class_object;

#endif	/* _JC_javax_print_attribute_standard_JobImpressionsSupported_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/JobImpressionsSupported.h <==
// public final class javax.print.attribute.standard.JobImpressionsSupported

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 918eb93a2f6dd324 javax_print_attribute_SetOfIntegerSyntax
// @dep_class eb46a4ecfecc3d56 javax_print_attribute_standard_JobImpressionsSupported

// header file dependencies
// @dep_header javax_print_attribute_SetOfIntegerSyntax

#include "javax/print/attribute/SetOfIntegerSyntax.h"

#ifndef _JC_javax_print_attribute_standard_JobImpressionsSupported_H_
#define _JC_javax_print_attribute_standard_JobImpressionsSupported_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_JobImpressionsSupported$sub_refs	_jc_javax_print_attribute_standard_JobImpressionsSupported$sub_refs;
typedef struct _jc_javax_print_attribute_standard_JobImpressionsSupported$sub_nonrefs	_jc_javax_print_attribute_standard_JobImpressionsSupported$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobImpressionsSupported$refs	_jc_javax_print_attribute_standard_JobImpressionsSupported$refs;
typedef struct _jc_javax_print_attribute_standard_JobImpressionsSupported$nonrefs	_jc_javax_print_attribute_standard_JobImpressionsSupported$nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobImpressionsSupported$object	_jc_javax_print_attribute_standard_JobImpressionsSupported$object;

typedef struct _jc_javax_print_attribute_standard_JobImpressionsSupported$fields_struct	_jc_javax_print_attribute_standard_JobImpressionsSupported$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_JobImpressionsSupported$vmethods	_jc_javax_print_attribute_standard_JobImpressionsSupported$vmethods;
typedef const struct _jc_javax_print_attribute_standard_JobImpressionsSupported$vtable	_jc_javax_print_attribute_standard_JobImpressionsSupported$vtable;
typedef const struct _jc_javax_print_attribute_standard_JobImpressionsSupported$vtype	_jc_javax_print_attribute_standard_JobImpressionsSupported$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24JobImpressionsSupported;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_JobImpressionsSupported$fields_struct _jc_javax_print_attribute_standard_JobImpressionsSupported$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_JobImpressionsSupported$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_javax_print_attribute_standard_JobImpressionsSupported$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobImpressionsSupported$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_JobImpressionsSupported$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_JobImpressionsSupported$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_JobImpressionsSupported$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_JobImpressionsSupported$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_JobImpressionsSupported$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobImpressionsSupported$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_JobImpressionsSupported$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_JobImpressionsSupported$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_SetOfIntegerSyntax$vmethods	javax_print_attribute_SetOfIntegerSyntax;
	_jc_javax_print_attribute_standard_JobImpressionsSupported$vmethods	javax_print_attribute_standard_JobImpressionsSupported;
};

// Vtype
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_JobImpressionsSupported$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$refs {
    _jc_javax_print_attribute_standard_JobImpressionsSupported$sub_refs	javax_print_attribute_standard_JobImpressionsSupported;
    _jc_javax_print_attribute_SetOfIntegerSyntax$sub_refs	javax_print_attribute_SetOfIntegerSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_SetOfIntegerSyntax$sub_nonrefs	javax_print_attribute_SetOfIntegerSyntax;
    _jc_javax_print_attribute_standard_JobImpressionsSupported$sub_nonrefs	javax_print_attribute_standard_JobImpressionsSupported;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_JobImpressionsSupported$object {
	_jc_javax_print_attribute_standard_JobImpressionsSupported$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_JobImpressionsSupported$vtype	*vtype;
	_jc_javax_print_attribute_standard_JobImpressionsSupported$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_JobImpressionsSupported$vtype _jc_javax_print_attribute_standard_JobImpressionsSupported$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_JobImpressionsSupported, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_JobImpressionsSupported$class_object;

#endif	/* _JC_javax_print_attribute_standard_JobImpressionsSupported_H_ */
